@@ -156,7 +156,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.3';
+    return '1.3.1';
   }
 
   
