@@ -312,7 +312,7 @@ if( !$opp['norotate'] && function_exists('exif_read_data') )
     if( $fn == 0 )
       {
 	// we can try to read the exif information to find an orientation.
-	$exif = exif_read_data($srcfile,0,TRUE);
+	$exif = @exif_read_data($srcfile,0,TRUE);
 	if( is_array($exif) && isset($exif['IFD0']) && isset($exif['IFD0']['Orientation']) &&
 	    is_int($exif['IFD0']['Orientation']) )
 	  {
